@@ -10,7 +10,7 @@ pickleFile = f"{author}.pickle"
 saveFile = f"Quotes.txt"
 
 # IF PICKLE FILE EXISTS THEN LOAD, OTHERWISE GENERATE FROM GOODREADS WEBSITE
-if os.path.isfile(saveFile):
+if os.path.isfile(pickleFile):
     db = gr.Quotes.loadDB(pickleFile)
 else:
     db = gr.Quotes.generateDB(author, saveFile=pickleFile)
